# cellular-automata-mandelbrot

This repository uses code from my repository https://github.com/ribhuhooja/conway-game-of-life to implement
a Mandelbrot set: https://en.wikipedia.org/wiki/Mandelbrot_set

Controls:  
Spacebar - toggle pause and unpause  
F - speed up  
S - slow down  
R - restart animation

# Installation instructions
You will need python and pygame to run this program.  
Installing python: https://www.python.org/downloads/  
Make sure to add it to path!  

Once you've done that, pip should be in path. In the command line, run  
```
pip install pygame
```

Now, you can download the files! Probably the best way to do that is to clone the repository.   
Once you have all the files for the repository, `cd` to that directory, and run  

```
python main.py
```
or
```
python3 main.py
```
(depending on your system)

# Video Demo
A video demo of the installation and running of the program:  
https://youtu.be/gbwE5QXcWP0

(This demo is for the old Conway's game of life, but the installation is basically the same
for this repository. The only difference is fewer controls,, as this is not meant to be interactive)
